package com.itbaizhan.travel.security;

import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.security.config.annotation.method.configuration.EnableGlobalMethodSecurity;
import org.springframework.security.config.annotation.web.builders.HttpSecurity;
import org.springframework.security.config.annotation.web.configuration.WebSecurityConfigurerAdapter;
import org.springframework.security.crypto.bcrypt.BCryptPasswordEncoder;

@Configuration
@EnableGlobalMethodSecurity(prePostEnabled = true)
public class SecurityConfig extends WebSecurityConfigurerAdapter {
    @Override
    protected void configure(HttpSecurity http) throws Exception {
        //自定义表单登录
        http.formLogin()
                .loginPage("/backstage/admin_login") //自定义登录页面
                .usernameParameter("username")
                .passwordParameter("password")
                .loginProcessingUrl("/backstage/admin/login")//登录提交路径，提交后执行认证逻辑
                .successForwardUrl("/backstage/index")
                .failureForwardUrl("/backstage/admin_fail");

        //权限拦截配置
        http.authorizeRequests()
                .antMatchers("/backstage/admin/login").permitAll()//不需要认证
                .antMatchers("/backstage/admin_fail").permitAll()
                .antMatchers("/backstage/admin_login").permitAll()
                .antMatchers("/**/*.css","/**/*.js").permitAll()
                .antMatchers("/backstage/**").authenticated();//其余资源需要认证

        //退出登陆配置
        http.logout()
                .logoutUrl("/backstage/admin/logout")
                .logoutSuccessUrl("/backstage/admin_login")
                .clearAuthentication(true) //清除认证逻辑
                .invalidateHttpSession(true); //清除session

        //异常处理
        http.exceptionHandling()
                .accessDeniedHandler(new MyAccessDeniedHandler());//权限不足处理器

        //关闭csrf防护
        http.csrf().disable();

        //开启跨域访问
        http.cors();
    }
    //密码编译器
    @Bean
    public BCryptPasswordEncoder passwordEncoder(){
        return new BCryptPasswordEncoder();
    }
}
