package com.itbaizhan.travel.service;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.itbaizhan.travel.bean.PermissionWithStatus;
import com.itbaizhan.travel.bean.RoleWithStatus;
import com.itbaizhan.travel.mapper.PermissionMapper;
import com.itbaizhan.travel.mapper.RoleMapper;
import com.itbaizhan.travel.pojo.Permission;
import com.itbaizhan.travel.pojo.Role;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.List;

@Service
public class RoleService {
    @Autowired
    private RoleMapper roleMapper;
    @Autowired
    private PermissionMapper permissionMapper;

    public Page<Role> findPage(int page,int size){
        return roleMapper.selectPage(new Page(page,size),null);
    }

    public void addRole(Role role){
        roleMapper.insert(role);
    }

    public Role findById(Integer rid){
        Role role = roleMapper.selectById(rid);
        return role;
    }

    public void update(Role role){
        roleMapper.updateById(role);
    }

    public void delete(Integer rid){
        roleMapper.deleteById(rid);
    }

    //查询权限分配情况
    public List<PermissionWithStatus> findPermission(Integer rid){
        List<Permission> permissions = permissionMapper.selectList(null);
        List<Integer> pids = permissionMapper.findPermissionIdByRole(rid);
        List<PermissionWithStatus> permissionList=new ArrayList();
        for (Permission permission : permissions) {
            PermissionWithStatus permissionWithStatus = new PermissionWithStatus();
            BeanUtils.copyProperties(permission,permissionWithStatus);
            if(pids.contains(permission.getPid())){
                permissionWithStatus.setRoleHas(true);
            }else{
                permissionWithStatus.setRoleHas(false);
            }
            permissionList.add(permissionWithStatus);
        }
        return permissionList;
    }

    //重新分配角色权限
    public void updateRolePermission(Integer rid,Integer[] ids){
        roleMapper.deleteRoleAllPermission(rid);
        for (Integer pid : ids) {
            roleMapper.addRolePermission(rid,pid);
        }
    }
}
